==> sugarbowl-0.49.0.tar.gz: sugarbowl-0.49.0/sugarbowl/stylize.py <==
from .function import Function
from .merge_dicts import merge_dicts


class stylize(Function):
    """Format value with style.
    """

    # Public

    modes = {
        'bold': 1,
        'underline': 4,
    }

    layers = {
        'foreground': 30,
        'background': 40,
    }

    colors = {
        'black': 0,
        'red': 1,
        'green': 2,
        'yellow': 3,
        'blue': 4,
        'magenta': 5,
        'cyan': 6,
        'white': 7,
        'bright_black': 60,
        'bright_red': 61,
        'bright_green': 62,
        'bright_yellow': 63,
        'bright_blue': 64,
        'bright_magenta': 65,
        'bright_cyan': 66,
        'bright_white': 67,
    }

    def __init__(self, value, *, modes={}, layers={}, colors={}, **style):
        self.__value = value
        self.__style = style
        self.__modes = merge_dicts(self.modes, modes)
        self.__layers = merge_dicts(self.layers, layers)
        self.__colors = merge_dicts(self.colors, colors)

    def __call__(self):
        result = str(self.__value)
        offsets = self.__make_offsets()
        if offsets:
            open_code = self.__make_open_code(offsets)
            close_code = self.__make_close_code()
            result = open_code + result + close_code
        return result

    # Private

    __codes = {
        'beg': '\x1b[',
        'sep': ';',
        'end': 'm'
    }

    def __make_offsets(self):
        offsets = []
        for key, value in self.__style.items():
            try:
                if key in self.__layers:
                    offset = self.__layers[key] + self.__colors[value]
                elif value:
                    offset = self.__modes[key]
            except Exception:
                raise ValueError(
                    'Bad value "{value}" for key "{key}"'.
                    format(value=value, key=key))
            offsets.append(offset)
        return offsets

    def __make_open_code(self, offsets):
        style_code = self.__codes['sep'].join(map(str, sorted(offsets)))
        code = self.__codes['beg'] + style_code + self.__codes['end']
        return code

    def __make_close_code(self):
        return self.__codes['beg'] + self.__codes['end']

==> sugarbowl-0.50.0.tar.gz: sugarbowl-0.50.0/sugarbowl/stylize.py <==
from .function import Function
from .merge_dicts import merge_dicts


class stylize(Function):
    """Format string with style.
    """

    # Public

    modes = {
        'bold': 1,
        'underline': 4,
    }

    layers = {
        'foreground': 30,
        'background': 40,
    }

    colors = {
        'black': 0,
        'red': 1,
        'green': 2,
        'yellow': 3,
        'blue': 4,
        'magenta': 5,
        'cyan': 6,
        'white': 7,
        'bright_black': 60,
        'bright_red': 61,
        'bright_green': 62,
        'bright_yellow': 63,
        'bright_blue': 64,
        'bright_magenta': 65,
        'bright_cyan': 66,
        'bright_white': 67,
    }

    def __init__(self, string, *, modes={}, layers={}, colors={}, **style):
        self.__string = string
        self.__modes = merge_dicts(self.modes, modes)
        self.__layers = merge_dicts(self.layers, layers)
        self.__colors = merge_dicts(self.colors, colors)
        self.__style = style

    def __call__(self):
        result = self.__string
        offsets = self.__make_offsets()
        if offsets:
            open_code = self.__make_open_code(offsets)
            close_code = self.__make_close_code()
            result = open_code + result + close_code
        return result

    # Private

    __codes = {
        'beg': '\x1b[',
        'sep': ';',
        'end': 'm'
    }

    def __make_offsets(self):
        offsets = []
        for key, value in self.__style.items():
            try:
                if key in self.__layers:
                    offset = self.__layers[key] + self.__colors[value]
                elif value:
                    offset = self.__modes[key]
            except Exception:
                raise ValueError(
                    'Bad value "{value}" for key "{key}"'.
                    format(value=value, key=key))
            offsets.append(offset)
        return offsets

    def __make_open_code(self, offsets):
        style_code = self.__codes['sep'].join(map(str, sorted(offsets)))
        code = self.__codes['beg'] + style_code + self.__codes['end']
        return code

    def __make_close_code(self):
        return self.__codes['beg'] + self.__codes['end']
